@@ -8,7 +8,7 @@
 #
 package IO::Socket::Timeout;
 {
-  $IO::Socket::Timeout::VERSION = '0.15';
+  $IO::Socket::Timeout::VERSION = '0.16';
 }
 
 use strict;
@@ -107,6 +107,7 @@ sub socketpair::with::timeout {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -115,7 +116,7 @@ IO::Socket::Timeout - IO::Socket with read/write timeout
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -229,7 +230,7 @@ When a timeout (read, write) is hit on the socket, the function trying to be
 performed will return C<undef>, and C<$!> will be set to C<ETIMEOUT>.
 
 The socket will be marked as invalid internally, and any subsequential use of
-it will return C<undef>, and $! will be set to C<ECONNRESET>.
+it will return C<undef>, and C<$!> will be set to C<ECONNRESET>.
 
 Why invalid the socket ? If you read a socket, waiting for message A, and hit a
 timeout, if you then reuse the socket to read a message B, you might receive
@@ -238,7 +239,7 @@ because the sender mught not be reachable (that's probably why you got a
 timeout in the first place). So after a timeout failure, it's important that
 you recreate the socket.
 
-You can import ETIMEOUT and ECONNRESET by using C<POSIX>:
+You can import C<ETIMEOUT> and C<ECONNRESET> by using C<POSIX>:
 
   use Errno qw(ETIMEDOUT ECONNRESET);
 
@@ -286,4 +287,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
